==================
Usage instructions
==================

In this section you can find some advice how to use spechomo for spectral homogenization of multispectral satellite
data.


.. todo::

   This section is not yet complete but will be continously updated in future.
   If you miss topics, feel free to suggest new entries here!


.. toctree::
    :maxdepth: 4

    usage/input_data_requirements.rst
    usage/available_transformations.rst
    usage/homogenization.rst
    usage/classifier_creation.rst


.. seealso::

    For details regarding the implemented algorithm, example use cases and quality evaluations
    refer to the following paper:
    `Scheffler et al. 2020 <https://doi.org/10.1016/j.rse.2020.111723>`__
